@@ -8,19 +8,23 @@ This module is developed by:
     Joy Cheung <joycheung1994@gmail.com>
     Yalin Li <zoe.yalin.li@gmail.com>
 
-Part of the code is based on the thermosteam package:
+Part of this module is based on the Thermosteam package:
 https://github.com/BioSTEAMDevelopmentGroup/thermosteam
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
 
 import thermosteam as tmo
-from chemicals.elements import molecular_weight, charge_from_formula
-from chemicals.elements import mass_fractions as get_mass_frac
-from .utils.cod import cod_test_stoichiometry, electron_acceptor_cod
+from chemicals.elements import (
+    mass_fractions as get_mass_frac,
+    molecular_weight,
+    charge_from_formula
+    )
+from . import Chemical
+from .utils import auom, cod_test_stoichiometry, electron_acceptor_cod
 
 __all__ = ('Component',)
 
@@ -28,6 +32,7 @@ isinstance = isinstance
 
 _chemical_fields = tmo._chemical._chemical_fields
 _checked_properties = tmo._chemical._checked_properties
+lock_phase = tmo._chemical.lock_phase
 display_asfunctor = tmo._chemical.display_asfunctor
 copy_maybe = tmo.utils.copy_maybe
 
@@ -59,23 +64,22 @@ _key_component_properties = ('particle_size', 'degradability', 'organic',
 _component_properties = ('measured_as', 'description', 
                          *_key_component_properties)
                          
-_component_slots = (*tmo.Chemical.__slots__,
+_component_slots = (*Chemical.__slots__,
                     *tuple('_'+i for i in _component_properties))
 
 _checked_properties = (*_checked_properties, *_key_component_properties)
 
-AbsoluteUnitsOfMeasure = tmo.units_of_measure.AbsoluteUnitsOfMeasure
 component_units_of_measure = {
-    'i_C': AbsoluteUnitsOfMeasure('g'), 
-    'i_N': AbsoluteUnitsOfMeasure('g'), 
-    'i_P': AbsoluteUnitsOfMeasure('g'), 
-    'i_K': AbsoluteUnitsOfMeasure('g'), 
-    'i_Mg': AbsoluteUnitsOfMeasure('g'), 
-    'i_Ca': AbsoluteUnitsOfMeasure('g'), 
-    'i_mass': AbsoluteUnitsOfMeasure('g'), 
-    'i_charge': AbsoluteUnitsOfMeasure('mol'),
-    'i_COD': AbsoluteUnitsOfMeasure('g'),
-    'i_NOD': AbsoluteUnitsOfMeasure('g'),
+    'i_C': auom('g'), 
+    'i_N': auom('g'), 
+    'i_P': auom('g'), 
+    'i_K': auom('g'), 
+    'i_Mg': auom('g'), 
+    'i_Ca': auom('g'), 
+    'i_mass': auom('g'), 
+    'i_charge': auom('mol'),
+    'i_COD': auom('g'),
+    'i_NOD': auom('g'),
     }
 
 
@@ -106,11 +110,67 @@ def check_return_property(name, value):
 # Define the Component class
 # =============================================================================
 
-class Component(tmo.Chemical):
+class Component(Chemical):
     '''
     A subclass of :class:`thermosteam.Chemical` with additional attributes
     and methods for waste treatment.
 
+    Parameters
+    ----------
+    ID : str
+        ID for the component, must be unique.
+    search_ID : str
+        ID that will be passed to :class:`thermosteam.Chemical` to search the database.
+    formula : str
+        Formula for the component, formula from the database will be used
+        if the component is constructed from the database and it has a formula in the database.
+    phase : str
+        If provided, this component will be assumed to only exist in the given phase.
+    i_C : float
+        Carbon content of the component, [g C/g measure unit].
+    i_N : float
+        Nitrogen content of the component, [g N/g measure unit].
+    i_P : float
+        Phosphorus content of the component, [g P/g measure unit].
+    i_K : float
+        Potassium content of the component, [g K/g measure unit].
+    i_Mg : float
+        Magnesium content of the component, [g Mg/g measure unit].
+    i_Ca : float
+        Calcium content of the component, [g Ca/g measure unit].
+    i_mass : float
+        Mass content of the component, [g Component/g measure unit].
+    i_charge : float
+        Charge content of the component, [mol +/g measure unit].
+        Positive values indicate cations and negative values indicate anions.
+    i_COD : float
+        COD content, calculated based on `measured_as`, `organic`, and `formula` if not given.
+    i_NOD : float
+        Nitrogenous oxygen demand, calculated based on `measured_as`,
+        `degradability`, and `formula` if not given.
+    f_BOD5_COD : float
+        BOD5 fraction in COD of the component, unitless.
+    f_uBOD_COD : float        
+        Ultimate BOD fraction in COD of the component, unitless.
+    f_Vmass_Totmass : float        
+        Volatile fraction of the mass of the component, unitless.
+    description : str
+        Description of the component.
+    measured_as : str
+        The unit as which the component is measured.
+        Can be left as blank or chosen from 'COD', or a constituent 
+        element of the component.
+    particle_size : str
+        Size of the component based on the type.
+        Must be chosen from 'Dissolved gas', 'Soluble', 'Colloidal', or 'Particulate'.
+    degradability : str
+        Degradability of the Component.
+        Must be chosen from 'Readily', 'Slowly', or 'Undegradable'.
+    organic : bool
+        True (organic) or False (inorganic).
+    chemical_properties : kwargs
+        Will be passed to :class:`thermosteam.Chemical`.
+
     .. note::
         
         [1] Element ratios like `i_C`, `i_N`, `i_P`, `i_K`, `i_Mg`, and `i_Ca` will
@@ -120,6 +180,15 @@ class Component(tmo.Chemical):
         [2] For fractions including `f_BOD5_COD`, `f_uBOD_COD`, and `f_Vmass_Totmass`,
         their values must be within [0, 1].
         
+        [3] If no formula or MW is provided, then MW of this component is assumed to
+        1 to avoid ZeroDivisionError exception in calculation.
+    
+    
+    Examples
+    --------
+    `Component and WasteStream <https://qsdsan.readthedocs.io/en/latest/tutorials/Component_and_WasteStream.html>`_
+    
+    
     See Also
     --------
     `thermosteam.Chemical <https://thermosteam.readthedocs.io/en/latest/Chemical.html>`_
@@ -127,13 +196,13 @@ class Component(tmo.Chemical):
 
     __slots__ = _component_slots
 
-    def __new__(cls, ID='', search_ID=None, formula=None, phase=None, measured_as=None, 
+    # ID must be provided
+    def __new__(cls, ID, search_ID=None, formula=None, phase=None, measured_as=None, 
                 i_C=None, i_N=None, i_P=None, i_K=None, i_Mg=None, i_Ca=None,
                 i_mass=None, i_charge=None, i_COD=None, i_NOD=None,
                 f_BOD5_COD=None, f_uBOD_COD=None, f_Vmass_Totmass=None,
                 description=None, particle_size=None,
                 degradability=None, organic=None, **chemical_properties):
-        
         if search_ID:
             self = super().__new__(cls, ID=ID, search_ID=search_ID,
                                    search_db=True, **chemical_properties)
@@ -144,7 +213,7 @@ class Component(tmo.Chemical):
         if formula:
             self._formula = None
             self.formula = formula
-        if phase: tmo._chemical.lock_phase(self, phase)
+        if phase: lock_phase(self, phase)
 
         self._measured_as = measured_as
         self.i_mass = i_mass
@@ -396,7 +465,7 @@ class Component(tmo.Chemical):
 
     @property
     def organic(self):
-        '''[bool] True (organic) or False (inorganic)'''
+        '''[bool] True (organic) or False (inorganic).'''
         return self._organic
     @organic.setter
     def organic(self, organic):
@@ -405,7 +474,7 @@ class Component(tmo.Chemical):
 
     @property
     def i_COD(self):
-        '''[float] COD content, calculated based on `measured_as`, `organic` and `formula`.'''
+        '''[float] COD content, calculated based on `measured_as`, `organic`, and `formula` if not given.'''
         return self._i_COD or 0.
     @i_COD.setter
     def i_COD(self, i):
@@ -431,7 +500,7 @@ class Component(tmo.Chemical):
     def i_NOD(self):
         '''
         [float] Nitrogenous oxygen demand, calculated based on `measured_as`,
-        `degradability` and `formula`.'''
+        `degradability`, and `formula` if not given.'''
         return self._i_NOD or 0.        
     @i_NOD.setter
     def i_NOD(self, i):
@@ -503,12 +572,12 @@ class Component(tmo.Chemical):
                 missing.append(i)
         return missing
 
-    def copy(self, ID, **data):
+    def copy(self, new_ID, **data):
         '''
         Return a new :class:`Component` object with the same settings with
         alternative data set by kwargs.
         '''
-        new = self.__class__.__new__(cls=self.__class__, ID=ID)
+        new = self.__class__.__new__(cls=self.__class__, ID=new_ID)
 
         for field in self.__slots__:
             #!!! Take '_other_names' out after thermosteam is updated
@@ -516,7 +585,7 @@ class Component(tmo.Chemical):
             value = getattr(self, field)
             setattr(new, field, copy_maybe(value))
 
-        new._ID = ID
+        new._ID = new_ID
         new._locked_state = self._locked_state
         new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Sfus, new.Tm,
                            new.Tb, new.eos, new.eos_1atm, new.phase_ref)
@@ -539,7 +608,7 @@ class Component(tmo.Chemical):
             chemical = ID
 
         if isinstance(chemical, str):
-            chemical = tmo.Chemical(chemical)
+            chemical = Chemical(chemical)
 
         for field in chemical.__slots__:
             value = getattr(chemical, field, None)
@@ -564,9 +633,9 @@ class Component(tmo.Chemical):
         new.f_uBOD_COD = f_uBOD_COD
         new.f_Vmass_Totmass = f_Vmass_Totmass
         new.description = description
-        new.particle_size = particle_size
-        new.degradability = degradability
-        new.organic = organic
+        new._particle_size = particle_size
+        new._degradability = degradability
+        new._organic = organic
         new.i_COD = i_COD
         new.i_NOD = i_NOD
         for i,j in data.items():
