@@ -8,27 +8,25 @@ This module is developed by:
     Yalin Li <zoe.yalin.li@gmail.com>
     Joy Cheung <joycheung1994@gmail.com>
 
-Part of the code is based on the thermosteam package:
+Part of this module is based on the Thermosteam package:
 https://github.com/BioSTEAMDevelopmentGroup/thermosteam
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
 import numpy as np
 import pandas as pd
 import thermosteam as tmo
-from thermosteam import Chemical, Chemicals, CompiledChemicals
-from . import _component
-from .utils.loading import load_data
+from . import _component, Chemical, Chemicals, CompiledChemicals, Component
+from .utils import load_data
 
 __all__ = ('Components', 'CompiledComponents')
 
 setattr = object.__setattr__
 
 utils = tmo.utils
-Component = _component.Component
 _component_properties = _component._component_properties
 _num_component_properties = _component._num_component_properties
 _key_component_properties = _component._key_component_properties
@@ -57,6 +55,10 @@ class Components(Chemicals):
     A subclass of :class:`thermosteam.Chemicals`, contains :class:`Component`
     objects as attributes.
     
+    Examples
+    --------
+    `Component and WasteStream <https://qsdsan.readthedocs.io/en/latest/tutorials/Component_and_WasteStream.html>`_
+    
     See Also
     --------
     `thermosteam.Chemicals <https://thermosteam.readthedocs.io/en/latest/Chemicals.html>`_
@@ -251,7 +253,7 @@ class Components(Chemicals):
         del os
         new = cls.load_from_file(path=path, use_default_data=True, store_data=True)
 
-        H2O = Component.from_chemical('H2O', tmo.Chemical('H2O'),
+        H2O = Component.from_chemical('H2O', Chemical('H2O'),
                                       i_charge=0, f_BOD5_COD=0, f_uBOD_COD=0,
                                       f_Vmass_Totmass=0, description="Water",
                                       particle_size='Soluble',
@@ -264,20 +266,20 @@ class Components(Chemicals):
                 i.default()
                 
                 if not i.Tb:
-                    if i.particle_size == 'Soluble': i.Tb = tmo.Chemical('urea').Tb
-                    elif i.particle_size == 'Dissolved gas': i.Tb = tmo.Chemical('CO2').Tb
-                    else: i.Tb = tmo.Chemical('NaCl').Tb
+                    if i.particle_size == 'Soluble': i.Tb = Chemical('urea').Tb
+                    elif i.particle_size == 'Dissolved gas': i.Tb = Chemical('CO2').Tb
+                    else: i.Tb = Chemical('NaCl').Tb
                 
                 if (isa(i.V, _TMH) and (len(i.V.models)==0 or (i.V[0].Tmin > 298.15 or i.V[0].Tmax < 298.15))) or (isa(i.V, _PH) and (len(i.V.l.models)==0 or (i.V.l[0].Tmin > 298.15 or i.V.l[0].Tmax < 298.15))): 
                     if i.particle_size == 'Soluble': 
-                        i.copy_models_from(tmo.Chemical('urea'), names=('V',))                        
+                        i.copy_models_from(Chemical('urea'), names=('V',))                        
                     elif i.particle_size in ('Particulate', 'Colloidal'):
                         try: i.V.add_model(1.2e-5)
                         except AttributeError: 
                             i.V.l.add_model(1.2e-5)    # m^3/mol
                             i.V.s.add_model(1.2e-5)
                     else:
-                        i.copy_models_from(tmo.Chemical('CO2'), names=('V',))
+                        i.copy_models_from(Chemical('CO2'), names=('V',))
                       
                     
                 for j in ('sigma', 'epsilon', 'kappa', 'Cn', 'mu', 'Psat', 'Hvap'):
@@ -286,7 +288,8 @@ class Components(Chemicals):
                     i.copy_models_from(H2O, names=(j,))
             
             new.compile()
-        return new        
+        return new
+
 
 
 # %%
