@@ -5,11 +5,11 @@ QSDsan: Quantitative Sustainable Design for sanitation and resource recovery sys
 This module is developed by:
     Joy Cheung <joycheung1994@gmail.com>
 
-Part of the code is based on the thermosteam package:
+Part of this module is based on the Thermosteam package:
 https://github.com/BioSTEAMDevelopmentGroup/thermosteam
 
-This module is under the UIUC open-source license. Please refer to 
-https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+This module is under the University of Illinois/NCSA Open Source License.
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
@@ -561,14 +561,14 @@ class CompiledProcesses(Processes):
         rates = [r.subs(self._parameters) for r in self._production_rates]
         return pd.DataFrame(rates, index=self._components.IDs, columns=('rate_of_production',))
     
-    @property
-    def production_rates_function(self):
-        '''
-        [function] A function object of the components' rates of production. 
-        When evaluated, returns a list of production rates.
-        '''
-        args = list(symbols(self._components.IDs)) + [v for k,v in self._parameters.items() if k == str(v)]
-        return lambdify(args, self._production_rates)
+    # @property
+    # def production_rates_function(self):
+    #     '''
+    #     [function] A function object of the components' rates of production. 
+    #     When evaluated, returns a list of production rates.
+    #     '''
+    #     args = list(symbols(self._components.IDs)) + [v for k,v in self._parameters.items() if k == str(v)]
+    #     return [lambdify(args, r) for r in self._production_rates]
     
     def subgroup(self, IDs):
         '''Create a new subgroup of :class:`CompiledProcesses` objects.'''
