@@ -8,23 +8,30 @@ This module is developed by:
     Joy Cheung <joycheung1994@gmail.com>
     Yalin Li <zoe.yalin.li@gmail.com>
 
-Part of the code is based on the thermosteam package:
+Part of this module is based on the Thermosteam package:
 https://github.com/BioSTEAMDevelopmentGroup/thermosteam
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
+'''
+TODO:
+    Check compatibility for multiphase for phase-equilibrium
+'''
+
+
+
 # %%
 
 import numpy as np
-from thermosteam import Stream, MultiStream, utils, settings
-from . import Components
-from ._units_of_measure import auom
+from thermosteam import utils, settings
+from . import Components, Stream, MultiStream, SanStream, MissingSanStream, \
+    set_thermo
+from .utils import auom
 
-
-__all__ = ('WasteStream',)
+__all__ = ('WasteStream', 'MissingWasteStream')
 
 
 _defined_composite_vars = ('COD', 'BOD5', 'BOD', 'uBOD', 'NOD', 'ThOD', 'cnBOD',
@@ -109,48 +116,106 @@ def _calib_XBsub_fBODCOD(components, concentrations, substrate_IDs, BOD):
 # =============================================================================
 
 _load_components = settings.get_default_chemicals
-_set_thermo = settings.set_thermo
 
-class WasteStream(Stream):
+class WasteStream(SanStream):
     '''
-    A subclass of :class:`thermosteam.Stream` with additional attributes
-    and methods for waste treatment.
+    A subclass of :class:`~.SanStream` with additional attributes and methods
+    for wastewater.
+    
+    .. note::
+        
+        [1] Parameters below only include the ones additional to those of
+        :class:`thermosteam.Stream`.
+        
+        [2] Properties not defined during during initiation will be calculated
+        using :func:`WasteStream.composite`.
+    
+    
+    Parameters
+    ----------
+    pH : float
+        pH of the stream, unitless.
+    SAlk : float
+        Alkalinity, in meq/L (or mmol HCO3-/L). Assumed to be mainly bicarbonate.
+    COD : float
+        Chemical oxygen demand, in mg/L.
+    BOD : float
+        Biochemical oxygen demand, in mg/L, same as BOD5.
+    uBOD : float
+        Ultimate biochemical oxygen demand, in mg/L.
+    cnBOD : float
+        Carbonaceous nitrogenous BOD, in mg/L. Biochemical oxygen demand including nitrification.
+    ThOD : float
+        Theoretical oxygen demand, in mg/L.
+    TC : float
+        Total carbon, in mg/L.
+    TOC : float
+        Total organic carbon, in mg/L.
+    TN : float
+        Total nitrogen, in mg/L.
+    TKN : float
+        Total Kjeldahl nitrogen, in mg/L.
+    TP : float
+        Total phosphorus, in mg/L.
+    TK : float
+        Total potassium, in mg/L.
+    TMg : float
+        Total magnesium, in mg/L.
+    TCa : float
+        Total calcium, in mg/L.
+    dry_mass : float
+        Total solids, dry mass of dissolved and suspended solids, in mg/L.
+    charge : float
+        TO BE IMPLEMENTED
+    ratios : float
+        TO BE IMPLEMENTED
+    impact_item : :class:`StreamImpactItem`
+        The :class:`StreamImpactItem` this stream is linked to.
+    component_flows : kwargs
+        Component flow data.
+    
+    
+    Examples
+    --------
+    `Component and WasteStream <https://qsdsan.readthedocs.io/en/latest/tutorials/Component_and_WasteStream.html>`_
     
     See Also
     --------
     `thermosteam.Stream <https://thermosteam.readthedocs.io/en/latest/Stream.html>`_
-    
     '''
     
-    # Child class will inherit parent class's slots
-    __slots__ = _ws_specific_slots
+    __slots__ = SanStream.__slots__ + _ws_specific_slots
     _default_ratios = _default_ratios
     ticket_name = 'ws'
     
     def __init__(self, ID='', flow=(), phase='l', T=298.15, P=101325.,
                  units='kg/hr', price=0., thermo=None, 
                  pH=7., SAlk=2.5, COD=None, BOD=None, uBOD=None,
+                 ThOD=None, cnBOD=None,
                  TC=None, TOC=None, TN=None, TKN=None, TP=None, TK=None,
                  TMg=None, TCa=None, dry_mass=None, charge=None, ratios=None,
-                 ThOD=None, cnBOD=None, impact_item=None, **chemical_flows):
+                 impact_item=None, **component_flows):
         
-        super().__init__(ID=ID, flow=flow, phase=phase, T=T, P=P,
-                         units=units, price=price, thermo=thermo, **chemical_flows)
+        SanStream.__init__(self=self, ID=ID, flow=flow, phase=phase, T=T, P=P,
+                           units=units, price=price, thermo=thermo,
+                           impact_item=impact_item, **component_flows)
         
         self._init_ws(pH, SAlk, COD, BOD, uBOD, TC, TOC, TN, TKN,
-                      TP, TK, TMg, TCa, ThOD, cnBOD, dry_mass, charge, ratios,
-                      impact_item)
+                      TP, TK, TMg, TCa, ThOD, cnBOD, dry_mass, charge, ratios)
 
     def _init_ws(self, pH=7., SAlk=None, COD=None, BOD=None,
-                  uBOD=None, TC=None, TOC=None, TN=None, TKN=None,
-                  TP=None, TK=None, TMg=None, TCa=None, ThOD=None, cnBOD=None,
-                  dry_mass=None, charge=None, ratios=None, impact_item=None):
+                 uBOD=None, ThOD=None, cnBOD=None,
+                 TC=None, TOC=None, TN=None, TKN=None,
+                 TP=None, TK=None, TMg=None, TCa=None,
+                 dry_mass=None, charge=None, ratios=None):
 
         self._pH = pH
         self._SAlk = SAlk
         self._COD = COD
         self._BOD = BOD
         self._uBOD = uBOD
+        self._ThOD = ThOD
+        self._cnBOD = cnBOD
         self._TC = TC
         self._TOC = TOC
         self._TN = TN
@@ -159,20 +224,69 @@ class WasteStream(Stream):
         self._TK = TK
         self._TMg = TMg
         self._TCa = TCa
-        self._ThOD = ThOD
-        self._cnBOD = cnBOD
         self._dry_mass = dry_mass
         self._charge = charge
         self._ratios = ratios
-        if impact_item:
-            impact_item._linked_stream = self
-        self._impact_item = impact_item
+
+    @staticmethod
+    def from_stream(cls, stream, ID=None, **kwargs):
+        '''
+        Cast a :class:`thermosteam.Stream` or :class:`biosteam.utils.MissingStream`
+        to :class:`WasteStream` or :class:`MissingWasteStream`.
+        
+        Parameters
+        ----------
+        cls : obj
+            class of the stream to be created.
+        stream : :class:`thermosteam.Stream`
+            The original stream.
+        ID : str
+            If not provided, will use the ID of the original stream.
+        kwargs
+            Additional properties of the new stream.
+            
+        Examples
+        --------
+        >>> import qsdsan as qs
+        >>> cmps = qs.Components.load_default()
+        >>> qs.set_thermo(cmps)
+        >>> s = qs.Stream('s', H2O=100, price=5)
+        >>> s.show()
+        Stream: s
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kmol/hr): H2O  100
+        >>> s.price
+        5.0
+        >>> ws = qs.WasteStream.from_stream(qs.WasteStream, s, ID='ws',
+        ...                                 T=250, price=8)
+        >>> ws.show()
+        WasteStream: ws
+         phase: 'l', T: 250 K, P: 101325 Pa
+         flow (g/hr): H2O  1.8e+06
+         WasteStream-specific properties:
+          pH         : 7.0
+        >>> ws.price
+        8.0
+        '''
+        
+        new = SanStream.from_stream(cls, stream, ID)
+        
+        if isinstance(new, MissingSanStream):
+            missing_new = MissingWasteStream.__new__(MissingWasteStream)
+            return missing_new
+                    
+        for attr, val in kwargs.items():
+            setattr(new, attr, val)
+        
+        new._init_ws()
+            
+        return new
 
     
     def show(self, T='K', P='Pa', flow='g/hr', composition=False, N=15,
              stream_info=True, details=True):
         '''
-        Print waste stream information.
+        Print information related to this :class:`WasteStream`.
 
         Parameters
         ----------
@@ -198,7 +312,7 @@ class WasteStream(Stream):
         info = ''
         # Stream-related specifications
         if stream_info:
-            super().show(T, P, flow, composition, N)
+            super().show(None, T, P, flow, composition, N)
         else:
             info += self._basic_info()
             display_units = self.display_units
@@ -215,9 +329,9 @@ class WasteStream(Stream):
         _ws_info = ' WasteStream-specific properties:'
         # Wastewater-related properties are not relevant for gas or solids
         if self.phase != 'l':
-            _ws_info += ' None for non-liquid WasteStreams'
+            _ws_info += ' None for non-liquid waste streams\n'
         elif self.F_mass == 0:
-            _ws_info += ' None for empty WasteStreams'
+            _ws_info += ' None for empty waste streams\n'
         else:
             _ws_info += '\n'
             # Only non-zero properties are shown
@@ -238,10 +352,6 @@ class WasteStream(Stream):
             
         return _ws_info
 
-    @property
-    def components(self):
-        return self.chemicals
-
     @property
     def ratios(self):
         '''
@@ -321,7 +431,7 @@ class WasteStream(Stream):
             if specification == 'TKN': 
                 IDs = [ID for ID in IDs if ID not in ('S_N2','S_NO2','S_NO3')]
             elif specification not in _specific_groups.keys():
-                raise KeyError(f"Undefined specification {specification}."
+                raise KeyError(f"Undefined specification {specification}. "
                                f"Must be one of {_specific_groups.keys()}."
                                "Or, try defining 'subgroup'.")
             else: 
@@ -384,16 +494,6 @@ class WasteStream(Stream):
         return (dummy*var).sum()
 
     
-    @property
-    def impact_item(self):
-        '''[StreamImpactItem] The :class:`StreamImpactItem` this waste stream is linked to.'''
-        return self._impact_item
-    @impact_item.setter
-    def impact_item(self, i):
-        self._impact_item = i
-        i.linked_stream = self
-
-    
     def _liq_sol_properties(self, prop, value):
         if self.phase != 'g':
             return getattr(self, '_'+prop) or value
@@ -407,7 +507,7 @@ class WasteStream(Stream):
 
     @property
     def SAlk(self):
-        '''[float] Alkalinity in meq/L (or mmol HCO3-/L). Assumed to be mainly bicarbonate.'''
+        '''[float] Alkalinity, in meq/L (or mmol HCO3-/L). Assumed to be mainly bicarbonate.'''
         return self._liq_sol_properties('SAlk', 0.)
 
     @property
@@ -493,20 +593,46 @@ class WasteStream(Stream):
     #     return self._liq_sol_properties('charge', self.composite('charge'))
     
 
-    def copy(self, ID=None):
-        new = super().copy()
-        new._init_ws()
-        for slot in _ws_specific_slots:
-            value = getattr(self, slot)
-            if slot == '_impact_item' and value:
-                value.copy(stream=new)
-            else:
-                setattr(new, slot, utils.copy_maybe(value))
+    def copy(self, new_ID='', ws_properties=True):
+        '''
+        Copy the information of another stream.
+        
+        Parameters
+        ----------
+        new_ID : str
+            ID of the new stream, a default ID will be assigned if not provided.
+        ws_properties : bool
+            Whether to copy wastewater-related properties to the new stream.
+        
+        
+        .. note::
+            
+            [1] Price of the original stream is not copied.
+            
+            [2] If the original stream has an :class:`~.StreamImpactItem`,
+            then a new :class:`~.StreamImpactItem` will be created for the new stream
+            and the new impact item will be linked to the original impact item.
+        '''
+        new = Stream.copy(self, ID=new_ID)
+        if ws_properties:
+            new._init_ws()
+            for slot in _ws_specific_slots:
+                value = getattr(self, slot)
+                if slot == '_impact_item' and value:
+                    value.copy(stream=new)
+                else:
+                    setattr(new, slot, utils.copy_maybe(value))
         return new
+    
     __copy__ = copy
 
+    # TODO: add documents for these functions, differentiate copy, copy_like, and copy_flow
     def copy_like(self, other):
         Stream.copy_like(self, other)
+        
+        if not isinstance(other, WasteStream):
+            return
+
         for slot in _ws_specific_slots:
             value = getattr(other, slot)
             setattr(self, slot, value)
@@ -537,12 +663,52 @@ class WasteStream(Stream):
                 setattr(self, slot, value)
 
     def mix_from(self, others):
+        '''
+        Update this stream to be a mixture of other streams,
+        initial content of this stream will be ignored.
+        
+        Parameters
+        ----------
+        others : iterable
+            Can contain :class:`thermosteam.Stream`, :class:`SanStream`,
+            or :class:`~.WasteStream`
+        
+        .. note::
+            
+            Price and impact item are not included.
+        
+            
+        Examples
+        --------
+        >>> import qsdsan as qs
+        >>> cmps = qs.Components.load_default()
+        >>> qs.set_thermo(cmps)
+        >>> s = qs.Stream('s', H2O=100, price=5, units='kg/hr')
+        >>> ss = qs.SanStream('ss', S_O2=100, units='kg/hr')
+        >>> ws = qs.WasteStream('ws')
+        >>> ws.mix_from((s, ss))
+        >>> ws.show()
+        WasteStream: ws
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (g/hr): S_O2  1e+05
+                      H2O   1e+05
+         WasteStream-specific properties:
+          pH         : 7.0
+        '''
+        
+        others = [s for s in others if not 'Missing' in type(s).__name__]
         Stream.mix_from(self, others)
+
         for slot in _ws_specific_slots:
+            if not hasattr(self, slot):
+                continue
             #!!! This need reviewing, might not be good to calculate some
             # attributes like pH
-            try: tot = sum(float(getattr(i, slot))*i.F_vol for i in others)
+            try:
+                tot = sum(float(getattr(i, slot))*i.F_vol for i in others
+                          if hasattr(i, slot))
             except: continue
+            
             if tot == 0.:
                 setattr(self, slot, None)
             else:
@@ -738,7 +904,7 @@ class WasteStream(Stream):
         cmps.X_B_Subst.i_N = XB_Substi_N
         cmps.X_B_Subst.i_P = XB_Substi_P
         cmps.compile()
-        _set_thermo(cmps)
+        set_thermo(cmps)
         
         #************ convert concentrations to flow rates *************
         flow_tot /= vol_unit.conversion_factor(units[0])
@@ -915,7 +1081,7 @@ class WasteStream(Stream):
         cmps.X_B_Subst.i_P = XB_Substi_P
         for i in sub_IDs: cmps[i].f_BOD5_COD = fbodtocod_sub
         cmps.compile()
-        _set_thermo(cmps)
+        set_thermo(cmps)
         
         #************ convert concentrations to flow rates *************
         flow_tot /= vol_unit.conversion_factor(units[0])
@@ -1087,7 +1253,7 @@ class WasteStream(Stream):
         cmps.X_B_Subst.i_P = XB_Substi_P
         for i in sub_IDs: cmps[i].f_BOD5_COD = fbodtocod_sub
         cmps.compile()
-        _set_thermo(cmps)
+        set_thermo(cmps)
 
         #************ convert concentrations to flow rates *************
         flow_tot /= vol_unit.conversion_factor(units[0])
@@ -1254,7 +1420,7 @@ class WasteStream(Stream):
         cmps.X_B_Subst.i_N = XB_Substi_N
         cmps.X_B_Subst.i_P = XB_Substi_P
         cmps.compile()
-        _set_thermo(cmps)
+        set_thermo(cmps)
 
         #************ convert concentrations to flow rates *************
         flow_tot /= vol_unit.conversion_factor(units[0])
@@ -1281,3 +1447,115 @@ class WasteStream(Stream):
         return new
 
 
+
+# %%
+
+class MissingWasteStream(MissingSanStream):
+    '''
+    A subclass of :class:`MissingSanStream`, create a special object
+    that acts as a dummy until replaced by an actual :class:`WasteStream`.
+    
+    .. note::
+        
+        Users usually do not need to interact with this class.
+    '''
+
+    # TODO: add others
+    @property
+    def pH(self):
+        '''[float] pH, unitless.'''
+        return 7.
+    
+    @property
+    def SAlk(self):
+        '''[float] Alkalinity.'''
+        return 0.
+    
+    @property
+    def COD(self):
+        '''[float] Chemical oxygen demand.'''
+        return 0.
+    
+    @property
+    def BOD(self):
+        '''[float] Biochemical oxygen demand, same as BOD5.'''
+        return 0.
+    
+    @property    
+    def BOD5(self):
+        '''[float] 5-day biochemical oxygen demand, same as BOD.'''
+        return self.BOD
+    
+    @property    
+    def uBOD(self):
+        '''[float] Ultimate biochemical oxygen demand.'''
+        return 0.
+    
+    @property    
+    def cnBOD(self):
+        '''[float] Carbonaceous nitrogenous BOD.'''
+        return 0.
+    
+    @property    
+    def ThOD(self):
+        '''[float] Theoretical oxygen demand.'''
+        return 0.
+    
+    @property
+    def TC(self):
+        '''[float] Total carbon.'''
+        return 0.
+    
+    @property
+    def TOC(self):
+        '''[float] Total organic carbon.'''
+        return 0.
+    
+    @property
+    def TN(self):
+        '''[float] Total nitrogen.'''
+        return 0.
+    
+    @property
+    def TKN(self):
+        '''[float] Total Kjeldahl nitrogen.'''
+        return 0.
+    
+    @property
+    def TP(self):
+        '''[float] Total phosphorus.'''
+        return 0.
+    
+    @property
+    def TK(self):
+        '''[float] Total potassium.'''
+        return 0.
+    
+    @property
+    def TMg(self):
+        '''[float] Total magnesium.'''
+        return 0.
+    
+    @property
+    def TCa(self):
+        '''[float] Total calcium.'''
+        return 0.
+    
+    @property
+    def dry_mass(self):
+        '''[float] Total solids.'''
+        return 0.
+    
+    #!!! Keep this up-to-date with WasteStream
+    # @property
+    # def charge(self):
+    #     return 0.
+
+    def __repr__(self):
+        return '<MissingWasteStream>'
+    
+    def __str__(self):
+        return 'missing waste stream'
+
+
+
