@@ -8,7 +8,7 @@ This module is developed by:
     Yalin Li <zoe.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
@@ -18,7 +18,7 @@ for license details.
 import numpy as np
 from .. import SanUnit, Construction
 from ._decay import Decay
-from ..utils.loading import load_data, data_path
+from ..utils import load_data, data_path
 
 __all__ = ('LiquidTreatmentBed',)
 
@@ -51,9 +51,10 @@ class LiquidTreatmentBed(SanUnit, Decay):
     
     '''
     
-    def __init__(self, ID='', ins=None, outs=(), if_N2O_emission=False, **kwargs):
+    def __init__(self, ID='', ins=None, outs=(), thermo=None, init_with='WasteStream',
+                 if_N2O_emission=False, **kwargs):
 
-        SanUnit.__init__(self, ID, ins, outs)
+        SanUnit.__init__(self, ID, ins, outs, thermo, init_with, F_BM_default=1)
         self.if_N2O_emission = if_N2O_emission
     
         data = load_data(path=data_path)
