@@ -8,7 +8,7 @@ This module is developed by:
     Yalin Li <zoe.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
@@ -17,11 +17,7 @@ for license details.
 
 from .. import WasteStream, Construction
 from ._toilet import Toilet
-from ..utils.loading import load_data, data_path
-
-# Note that here two different methods are used to check the user-input values
-from ..utils.checkers import Fraction as Frac_C
-from ..utils.descriptors import Fraction as Frac_D
+from ..utils import load_data, data_path
 
 __all__ = ('PitLatrine',)
 
@@ -65,23 +61,27 @@ class PitLatrine(Toilet):
     :ref:`qsdsan.sanunits.Toilet <sanunits_Toilet>`
     
     '''
+    
+    # Legacy code to add checkers
+    # _P_leaching = Frac_D(name='P_leaching')
 
-    _P_leaching = Frac_D(name='P_leaching')
-
-    def __init__(self, ID='', ins=None, outs=(), N_user=1, N_toilet=1, lifetime=8,
+    def __init__(self, ID='', ins=None, outs=(), thermo=None, init_with='WasteStream',
+                 N_user=1, N_toilet=1, lifetime=8,
                  if_toilet_paper=True, if_flushing=True, if_cleansing=False,
                  if_desiccant=False, if_air_emission=True, if_ideal_emptying=True, 
                  CAPEX=449, OPEX_over_CAPEX=0.05,
                  if_leaching=True, if_shared=True,
                  if_pit_above_water_table=True, **kwargs):
 
-        Toilet.__init__(self, ID, ins, outs, N_user, N_toilet,
+        Toilet.__init__(self, ID, ins, outs, thermo, init_with, N_user, N_toilet,
                         if_toilet_paper, if_flushing, if_cleansing, if_desiccant,
                         if_air_emission, if_ideal_emptying, CAPEX, OPEX_over_CAPEX)
+
         self.lifetime = lifetime
         self.if_leaching = if_leaching
         self.if_pit_above_water_table = if_pit_above_water_table
         self.if_shared = if_shared
+
         data = load_data(path=data_path)
         for para in data.index:
             if para in ('MCF_decay', 'N2O_EF_decay'):
@@ -90,6 +90,7 @@ class PitLatrine(Toilet):
                 value = float(data.loc[para]['expected'])
             setattr(self, '_'+para, value)
         del data
+
         self._pit_depth = 4.57 # m
         self._pit_area = 0.8 # m2
         self._liq_leaching = None
@@ -271,8 +272,10 @@ class PitLatrine(Toilet):
         return self._N_leaching
     @N_leaching.setter
     def N_leaching(self, i):
-        @Frac_C(self)
-        def N_leaching(): return i
+        self._N_leaching = float(i)
+        # Legacy code to add checkers
+        # @Frac_C(self)
+        # def N_leaching(): return i
 
     @property
     def P_leaching(self):
