@@ -8,7 +8,7 @@ This module is developed by:
     Yalin Li <zoe.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
@@ -19,7 +19,7 @@ import numpy as np
 from .. import Construction
 from ._decay import Decay
 from ._sludge_separator import SludgeSeparator
-from ..utils.loading import load_data, data_path
+from ..utils import load_data, data_path
 
 __all__ = ('SedimentationTank',)
 
@@ -59,10 +59,12 @@ class SedimentationTank(SludgeSeparator, Decay):
     
     '''
     
-    def __init__(self, ID='', ins=None, outs=(), split=None, settled_frac=None,
+    def __init__(self, ID='', ins=None, outs=(),thermo=None, init_with='WasteStream',
+                 split=None, settled_frac=None,
                  if_N2O_emission=False, **kwargs):    
         
-        SludgeSeparator.__init__(self, ID, ins, outs, split, settled_frac)
+        SludgeSeparator.__init__(self, ID, ins, outs, thermo, init_with,
+                                 split, settled_frac, F_BM_default=1)
         self.if_N2O_emission = if_N2O_emission
 
         data = load_data(path=data_path)
@@ -144,11 +146,6 @@ class SedimentationTank(SludgeSeparator, Decay):
             Construction(item='Excavation', quantity=design['Single roof area']+side_area, quantity_unit='m3'),
             )
         self.add_construction()
-    
-    _BM = {
-        'Concrete': 1,
-        'Excavation': 1        
-        }
 
     @property
     def tau(self):
