@@ -8,7 +8,7 @@ This module is developed by:
     Yalin Li <zoe.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
@@ -18,7 +18,7 @@ for license details.
 from warnings import warn
 from .. import SanUnit
 from ._decay import Decay
-from ..utils.loading import load_data, data_path
+from ..utils import load_data, data_path
 
 __all__ = ('Toilet',)
 
@@ -70,12 +70,13 @@ class Toilet(SanUnit, Decay, isabstract=True):
     
     '''
     
-    def __init__(self, ID='', ins=None, outs=(), N_user=1, N_toilet=1,
+    def __init__(self, ID='', ins=None, outs=(), thermo=None, init_with='WasteStream',
+                 N_user=1, N_toilet=1,
                  if_toilet_paper=True, if_flushing=True, if_cleansing=False,
                  if_desiccant=False, if_air_emission=True, if_ideal_emptying=True,
                  CAPEX=None, OPEX_over_CAPEX=None):
 
-        SanUnit.__init__(self, ID, ins, outs)
+        SanUnit.__init__(self, ID, ins, outs, thermo, init_with, F_BM_default=1)
         self._N_user = 1
         self._N_toilet = 1
         self.N_user = N_user
@@ -102,6 +103,7 @@ class Toilet(SanUnit, Decay, isabstract=True):
         
     _N_ins = 6
     _outs_size_is_fixed = False
+    # F_BM = {'Total toilets': 1}
 
     def _run(self):
         ur, fec, tp, fw, cw, des = self.ins
@@ -117,14 +119,12 @@ class Toilet(SanUnit, Decay, isabstract=True):
         'Plastic': 0.63,
         'Steel': 7900,
         'StainlessSteelSheet': 2.64
-        }    
-
-    _BM = {'Single toilet': 1, 'Total toilets': 1}
+        }
         
     def _cost(self):
-        self.purchase_costs['Single toilet'] = self.CAPEX
-        self.purchase_costs['Total toilets'] = self.CAPEX * self.N_toilet
-        self._add_OPEX = self.purchase_costs['Total toilets']*self.OPEX_over_CAPEX/365/24
+        self.baseline_purchase_costs['Total toilets'] = self.CAPEX * self.N_toilet
+        add_OPEX = self.baseline_purchase_costs['Total toilets']*self.OPEX_over_CAPEX/365/24
+        self._add_OPEX = {'Additional OPEX': add_OPEX}
 
 
     @staticmethod
