@@ -8,7 +8,7 @@ This module is developed by:
     Yalin Li <zoe.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
-Please refer to https://github.com/QSD-Group/QSDsan/blob/master/LICENSE.txt
+Please refer to https://github.com/QSD-Group/QSDsan/blob/main/LICENSE.txt
 for license details.
 '''
 
@@ -19,10 +19,11 @@ del os
 
 import pandas as pd
 
-__all__ = ('load_data', 'data_path')
+__all__ = ('load_data', 'data_path',)
  
 
 def load_data(path=None, sheet=None, **kwargs):
+    '''For data importing.'''
     kwargs.setdefault('index_col', 0)
     last_4 = path[-4:]
     if last_4 == '.tsv':
@@ -34,4 +35,7 @@ def load_data(path=None, sheet=None, **kwargs):
         except: data = pd.read_excel(path, engine='openpyxl', **kwargs)
     else:
         raise ValueError('Only tsv, csv, or xlsx files can be loaded.')
-    return data
\ No newline at end of file
+    return data
+
+
+    
\ No newline at end of file
